@@ -17,6 +17,7 @@ RESPONSE_TYPE_CODE = "code"
 REQUEST_METHOD_DELETE = "delete"
 REQUEST_METHOD_GET = "get"
 REQUEST_METHOD_POST = "post"
+REQUEST_METHOD_PUT = "put"
 
 
 class RequestHelper(object):
@@ -66,10 +67,16 @@ class RequestHelper(object):
             response = request_fn(url, headers=headers, json=params)
 
         response_json = None
-        try:
-            response_json = response.json()
-        except ValueError:
-            raise ServerException(response)
+        content_type = (
+            response.headers.get("content-type")
+            if response.headers is not None
+            else None
+        )
+        if content_type is not None and "application/json" in content_type:
+            try:
+                response_json = response.json()
+            except ValueError:
+                raise ServerException(response)
 
         status_code = response.status_code
         if status_code >= 400 and status_code < 500:
@@ -78,7 +85,10 @@ class RequestHelper(object):
             elif status_code == 403:
                 raise AuthorizationException(response)
             error = response_json.get("error")
-            raise BadRequestException(response, error=error)
+            error_description = response_json.get("error_description")
+            raise BadRequestException(
+                response, error=error, error_description=error_description
+            )
         elif status_code >= 500 and status_code < 600:
             raise ServerException(response)
 
